# biometatools

A repository of tools for performing meta analysis on high throughput
sequencing data and genome features defined as genomic regions. Sequencing
data are most often requested in indexed BAM file format and features in BED
file format.

Examples of some questions that these tools are useful for:

* What is the distribution of reads around the 5' ends of genes?
* What is the distribution of reads along the length of all mRNAs?

# Installation

```
pip install biometatools
```
